package com.example.workflow;

import org.camunda.bpm.engine.delegate.DelegateExecution;
import org.camunda.bpm.engine.delegate.JavaDelegate;
import org.springframework.jdbc.core.JdbcTemplate;

import javax.inject.Named;
import java.util.List;

@Named("CheckUser")
public class CheckUser implements JavaDelegate {

    private final JdbcTemplate jdbcTemplate;

    public CheckUser(JdbcTemplate jdbcTemplate) {
        this.jdbcTemplate = jdbcTemplate;
    }

    @Override
    public void execute(DelegateExecution execution) throws Exception {
        String email = (String) execution.getVariable("EmailAddress");
        String password = (String) execution.getVariable("password");

        boolean userExists = checkUser(email, password);
        execution.setVariable("checkUser", userExists);

        // ユーザーの存在確認結果をログに出力
        System.out.println("CheckUser: Email = " + email + ", user exists = " + userExists);

        // Camundaのプロセス変数に値が設定されたことを確認するログ出力
        System.out.println("Variable 'checkUser' set in Camunda with value: " + userExists);
    }

    private boolean checkUser(String email, String password) {
        String query = "SELECT id FROM users WHERE email = ? AND password = ?";
        List<Integer> ids = jdbcTemplate.query(query, new Object[]{email, password},
                (rs, rowNum) -> rs.getInt("id"));
        return !ids.isEmpty();
    }
}
